%define mainver %(echo $(echo %{version} | awk -F '.' '{print $1"."$2}'))
%define majorver %(echo $(echo %{version} | awk -F '.' '{print $1}'))

Summary:        The Tool Command Language implementation
Name:           tcl
Version:        8.6.13
Release:        2%{?dist}
License:        TCL
URL:            https://core.tcl-lang.org/tcl
Source0:        http://downloads.sourceforge.net/sourceforge/tcl/tcl-core%{version}-src.tar.gz
Source1:				tcl-rpm-macros-license.txt
Source2:				tcl-rpm-macros-readme.md
Patch0001:      tcl-8.6.12-autopath.patch
Patch0002:      tcl-8.6.12-conf.patch
Patch0003:      tcl-8.6.12-hidden.patch
Patch0004:      tcl-8.6.10-tcltests-path-fix.patch

BuildRequires:  systemtap-sdt-devel, zlib-devel
BuildRequires:  gcc, make, autoconf
Provides:       tcl(abi) = %{mainver}
Provides:       tcl-tcldict = %{version}

%description
Tool Command Language (Tcl) is an interpreted language and very portable
interpreter for that language. Tcl is embeddable and extensible, and has been
widely used since its creation in 1988 by John Ousterhout.

%package devel
Summary:  Tcl scripting language development environment
Requires: tcl = %{version}-%{release}

%description devel
Tool Command Language (Tcl) is an interpreted language and very portable
interpreter for that language. Tcl is embeddable and extensible, and has been
widely used since its creation in 1988 by John Ousterhout.

The package contains the development files and man pages.

%package -n tcl-rpm-macros
Summary:  Tcl scripting language rpm macros
Requires: tcl-devel = %{version}-%{release}

%description -n tcl-rpm-macros
Tool Command Language (Tcl) is an interpreted language and very portable
interpreter for that language. Tcl is embeddable and extensible, and has been
widely used since its creation in 1988 by John Ousterhout.

The package contains the rpm macros for other packages while building rpm package.


%prep
%autosetup -p1 -n tcl%{version}
rm -r compat/zlib
mkdir tcl-rpm-macros
cp %{SOURCE1} tcl-rpm-macros/LICENSE
cp %{SOURCE2} tcl-rpm-macros/README.md



%build
pushd unix
autoconf
%configure \
	--enable-dtrace \
	--enable-threads \
	--enable-symbols \
	--enable-shared

%make_build CFLAGS="%{optflags}" TCL_LIBRARY=%{_datadir}/%{name}%{mainver}
popd



%install
make install -C unix INSTALL_ROOT=%{buildroot} TCL_LIBRARY=%{_datadir}/%{name}%{mainver}

ln -s tclsh%{mainver} %{buildroot}%{_bindir}/tclsh
ln -s libtcl%{mainver}.so %{buildroot}%{_libdir}/libtcl.so

mkdir -p %{buildroot}/%{_libdir}/tcl%{mainver}
ln -s %{_libdir}/tclConfig.sh %{buildroot}/%{_libdir}/tcl%{mainver}/tclConfig.sh

mkdir -p %{buildroot}/%{_includedir}/tcl-private/{generic,unix}
find generic unix -name "*.h" -exec cp -p '{}' %{buildroot}/%{_includedir}/tcl-private/'{}' ';'
( cd %{buildroot}/%{_includedir}
	for i in *.h ; do
		[ -f %{buildroot}/%{_includedir}/tcl-private/generic/$i ] && ln -sf ../../$i %{buildroot}/%{_includedir}/tcl-private/generic ;
	done
)

# remove buildroot traces
sed -i -e "s|$PWD/unix|%{_libdir}|; s|$PWD|%{_includedir}/tcl-private|" %{buildroot}/%{_libdir}/tclConfig.sh
rm -rf %{buildroot}%{_datadir}/tcl%{mainver}/ldAix

# add tcl rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}
cat > %{buildroot}%{_rpmmacrodir}/macros.tcl << EOF
#Copyright (c) [2022] [Zhao Zhen]
#[Software Name] is licensed under Mulan PubL v2.
#You can use this software according to the terms and conditions of the Mulan PubL v2.
#You may obtain a copy of Mulan PubL v2 at:
#         http://license.coscl.org.cn/MulanPubL-2.0
#THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
#EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
#MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
#See the Mulan PubL v2 for more details.
%%_tcl_version %version
%%_tcl_main_version %mainver
%%_tcl_major_version %majorver
%%__tcl %{_bindir}/tclsh
%%_tcl_library %{_datadir}/%{name}%{mainver}
%%_tcl_sitearch %{_libdir}/tcl%{version}
%%_tcl_sitelib %{_datadir}/tcl%{version}
EOF




%check
pushd unix
make test
popd



%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig



%files
%license license.terms
%doc README.md changes
%{_bindir}/tclsh*
%{_datadir}/tcl%{mainver}
%exclude %{_datadir}/tcl%{mainver}/tclAppInit.c
%{_datadir}/tcl%{majorver}
%{_libdir}/libtcl%{mainver}.so
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_mandir}/mann/*
%dir %{_libdir}/tcl%{mainver}

%files devel
%{_includedir}/*
%{_libdir}/libtclstub%{mainver}.a
%{_libdir}/libtcl.so
%{_libdir}/tclConfig.sh
%{_libdir}/tclooConfig.sh
%{_libdir}/tcl%{mainver}/tclConfig.sh
%{_libdir}/pkgconfig/tcl.pc
%{_datadir}/tcl%{mainver}/tclAppInit.c

%files -n tcl-rpm-macros
%license tcl-rpm-macros/LICENSE
%doc tcl-rpm-macros/README.md
%{_rpmmacrodir}/macros.tcl



%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.6.13-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 02 2023 cunshunxia <cunshunxia@tencent.com> - 8.6.13-1
- upgrade to 8.6.13

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.6.12-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 8.6.12-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Feb 15 2023 Shuo Wang <abushwang@tencent.com> - 8.6.12-2
- add macro _tcl_sitearch _tcl_sitelib.

* Mon Jul 18 2022 Zhao Zhen <jeremiazhao@tencent.com> - 8.6.12-1
- Initial building.
